@@ -47,7 +47,7 @@
  *
  */
 
-/* 
+/*
  * Formulas for PAR, DAR, width and height relations:
  *
  * dar_n   w   par_n
@@ -57,7 +57,7 @@
  * par_n    h   dar_n
  * ----- =  - * -----
  * par_d    w   dar_d
- * 
+ *
  *         dar_n   par_d
  * w = h * ----- * -----
  *         dar_d   par_n
@@ -161,7 +161,7 @@ static GstCaps *
 gst_video_scale_get_capslist (void)
 {
   static GstCaps *caps = NULL;
-  static volatile gsize inited = 0;
+  static gsize inited = 0;
 
   if (g_once_init_enter (&inited)) {
     caps = gst_static_caps_get (&gst_video_scale_format_caps);
@@ -210,6 +210,11 @@ static void gst_video_scale_get_property (GObject * object, guint prop_id,
 
 #define gst_video_scale_parent_class parent_class
 G_DEFINE_TYPE (GstVideoScale, gst_video_scale, GST_TYPE_VIDEO_FILTER);
+GST_ELEMENT_REGISTER_DEFINE (videoscale, "videoscale",
+    GST_RANK_NONE, GST_TYPE_VIDEO_SCALE);
+
+static GstCapsFeatures *features_format_interlaced,
+    *features_format_interlaced_sysmem;
 
 static void
 gst_video_scale_class_init (GstVideoScaleClass * klass)
@@ -470,8 +475,11 @@ gst_video_scale_transform_caps (GstBaseTransform * trans,
 
     /* If the features are non-sysmem we can only do passthrough */
     if (!gst_caps_features_is_any (features)
-        && gst_caps_features_is_equal (features,
-            GST_CAPS_FEATURES_MEMORY_SYSTEM_MEMORY)) {
+        && (gst_caps_features_is_equal (features,
+                GST_CAPS_FEATURES_MEMORY_SYSTEM_MEMORY)
+            || gst_caps_features_is_equal (features, features_format_interlaced)
+            || gst_caps_features_is_equal (features,
+                features_format_interlaced_sysmem))) {
       gst_structure_set (structure, "width", GST_TYPE_INT_RANGE, 1, G_MAXINT,
           "height", GST_TYPE_INT_RANGE, 1, G_MAXINT, NULL);
 
@@ -1221,15 +1229,18 @@ gst_video_scale_src_event (GstBaseTransform * trans, GstEvent * event)
 static gboolean
 plugin_init (GstPlugin * plugin)
 {
-  if (!gst_element_register (plugin, "videoscale", GST_RANK_NONE,
-          GST_TYPE_VIDEO_SCALE))
-    return FALSE;
+  features_format_interlaced =
+      gst_caps_features_new (GST_CAPS_FEATURE_FORMAT_INTERLACED, NULL);
+  features_format_interlaced_sysmem =
+      gst_caps_features_copy (features_format_interlaced);
+  gst_caps_features_add (features_format_interlaced_sysmem,
+      GST_CAPS_FEATURE_MEMORY_SYSTEM_MEMORY);
 
   GST_DEBUG_CATEGORY_INIT (video_scale_debug, "videoscale", 0,
       "videoscale element");
   GST_DEBUG_CATEGORY_GET (CAT_PERFORMANCE, "GST_PERFORMANCE");
 
-  return TRUE;
+  return GST_ELEMENT_REGISTER (videoscale, plugin);
 }
 
 GST_PLUGIN_DEFINE (GST_VERSION_MAJOR,
